@@ -19,16 +19,16 @@ cmd setup_git_repo
 opts | while read opt ; do 
 	cmd reset_git_repo
 
-	cmd guilt-init $opt
+	cmd guilt init $opt
 	cmd list_files
-	shouldfail guilt-init $opt
+	shouldfail guilt init $opt
 	cmd list_files
 done
 
 cmd git branch other
 cmd git checkout other
 
-cmd guilt-init
+cmd guilt init
 cmd list_files
-shouldfail guilt-init
+shouldfail guilt init
 cmd list_files
