@@ -7,12 +7,12 @@ source $REG_DIR/scaffold
 
 cmd setup_repo
 
-cmd guilt-unapplied
+cmd guilt unapplied
 
-guilt-series | while read n; do
-	cmd guilt-push
+guilt series | while read n; do
+	cmd guilt push
 
-	cmd guilt-unapplied
+	cmd guilt unapplied
 
 	cmd list_files
 done
