@@ -7,16 +7,16 @@ source $REG_DIR/scaffold
 
 cmd setup_repo
 
-cmd guilt-delete mode
+cmd guilt delete mode
 
 cmd list_files
 
-cmd guilt-delete mode
+cmd guilt delete mode
 # FIXME: this should return a non-zero status, no?
 
 cmd list_files
 
-cmd guilt-delete add
+cmd guilt delete add
 
 cmd list_files
 
