@@ -7,14 +7,14 @@ source $REG_DIR/scaffold
 
 cmd setup_repo
 
-cmd guilt-push -n 2
+cmd guilt push -n 2
 
 cmd list_files
  
-shouldfail guilt-fork mode
+shouldfail guilt fork mode
 
 cmd list_files
  
-cmd guilt-fork foobar
+cmd guilt fork foobar
 
 cmd list_files
